@@ -11,3 +11,7 @@ from .model import Model
 from .normalization import LayerNormalization
 from .activations import gelu, gelu_exact, get_activation
 from .initializers import get_initializer
+
+from .wrappers import Concat
+
+import params_flow.utils as utils
